/*
 * Author: Melcher
 * Date: 23-5-2015
 */
using Microsoft.Win32;
using System;
using System.Drawing;
using System.Windows.Forms;
using System.Windows.Desktop;
using System.Windows.Media;
using System.Diagnostics;


namespace VoteRightNow
{
	public class MainForm : System.Windows.Forms.Form
	{
		public MainForm()
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
		}
		
		[STAThread]
		public static void Main(string[] args)
		{
			Application.Run(new MainForm());
		}
		
		private void InitializeComponent()
		{
			this.ClientSize = new System.Drawing.Size(1, 1);
			this.Text = "VoteRightNow";
			this.Name = "VoteRightNow";
			this.Opacity = 0;
			this.ShowInTaskbar = false;
			SendVoteToast();	
		}
		
		private void SendVoteToast() {
			Notification n = new Notification();
			n.HeaderText = "Self-Host Vote";
			n.BodyText = "You have been using this Longhorn build for a few hours now.  By using the Vote now button below, you can vote to let us know what you think of it.  To learn more, click this text.";
			n.IsBodyClickable = true;
			NotificationButton nb = new NotificationButton();
			nb.Text = "Vote Now";
			nb.ID = 1;
			n.AddButton(nb);
			NotificationButton nb1 = new NotificationButton();
			nb1.Text = "Later";
			nb1.ID = 2;
			n.AddButton(nb1);
			n.HeaderIcon = new ImageData("ThumbsUp.png");
			n.NotificationClickedEvent += new NotificationClickedEventHandler(NotificationClicked);
			n.Send();
		}
		
		private void NotificationClicked(object sender, NotificationClickedEventArgs e) {
			int ID = e.ID;
			switch (ID) {
				case 0:
					// Learn more
					this.OpenLonghornVoteInfoPage();
					break;
				case 1:
					// Votenow
					this.OpenSelfHostVotePage();
					break;
				case 2:
					// More time. This would reset the time
					break;
			}
			Application.Exit();
		}
		
		private void OpenLonghornVoteInfoPage() {
			Process.Start("IExplore.exe", "http://longhorn/selfhost/");
		}
		
		private void OpenSelfHostVotePage() {
			// Create a VoteNow key in the registry
			RegistryKey vkey = Registry.CurrentUser.OpenSubKey("Software", true);
			vkey.CreateSubKey("VoteNow");
			vkey.Close();
			// Add a value to indicate voting has took place
			Registry.CurrentUser.OpenSubKey("Software\\VoteNow", true).SetValue("VotedOn", this.GetBuildnumber());
			// Prepare URI to browse to
			string build = string.Concat(this.GetBuildnumber(), ".", this.GetBuildDateTime());
			string lab = this.GetLAB();
			string URI = string.Concat("http://winweb/selfhost2/?ballot=3&lab=", lab, "&build=", build);
			// Start IE with the URI
			Process.Start("IExplore.exe", URI);
		}
		
		private string GetBuildDateTime() {
			RegistryKey key = Registry.LocalMachine.OpenSubKey("Software\\Microsoft\\Windows NT\\CurrentVersion", true);
			string value = (string)key.GetValue("BuildLab");
			key.Close();
			string dateTime;
			
			if (this.GetLAB() != "main") {
				dateTime = value.Substring(13, 6);
			} else {
				dateTime = value.Substring(10, 6);
			}
			return dateTime;
		}
		
		private string GetLAB() {
			RegistryKey key = Registry.LocalMachine.OpenSubKey("Software\\Microsoft\\Windows NT\\CurrentVersion", true);
			string lab = (string)key.GetValue("BuildLab");
			this.Text = lab;
			key.Close();
			if (string.Compare("Lab01", 0, lab, 5, 5, true) == 0) {
			    	return "1";
			}
			if (string.Compare("Lab02", 0, lab, 5, 5, true) == 0) {
			    	return "2";
			}
			if (string.Compare("Lab21", 0, lab, 5, 5, true) == 0) {
			    	return "21";
			}
			if (string.Compare("Lab03", 0, lab, 5, 5, true) == 0) {
			    	return "3";
			}
			if (string.Compare("Lab04", 0, lab, 5, 5, true) == 0) {
			    	return "4";
			}
			if (string.Compare("Lab06", 0, lab, 5, 5, true) == 0) {
			    	return "6";
			}
			if (string.Compare("Lab07", 0, lab, 5, 5, true) == 0) {
			    	return "7";
			}
			if (string.Compare("main", 0, lab, 5, 4, true) != 0) {
			    	return "BadLab";
			}
			return "main";
		}
		
		private string GetBuildnumber() {
			RegistryKey key = Registry.LocalMachine.OpenSubKey("Software\\Microsoft\\Windows NT\\CurrentVersion", true);
			string buildNo = (string)key.GetValue("CurrentBuildNumber");
			return buildNo;
		}
		
	}
}
